==> ux-reward-wrap-3.0.3.tgz: package/lib/components/pageBuilder/ElementCollection/RewardWrap/Reward/Radar/index.js <==
import "core-js/modules/es6.regexp.match";
import "core-js/modules/es7.array.includes";
import "core-js/modules/es6.string.includes";
import "core-js/modules/es6.function.name";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import * as React from 'react';
import './index.css';
import AvatarImg from '../../../../../../components/common/avatarImg'; // import GetSpotPos from './GetSpotPos';

import GetSpotPos from './GetPosition';
import { getByteLen } from '../../../../../../helper';
import { jumpPerson } from '../../../../../../helper/jumpToPersonHome'; // import * as ReactDom from 'react-dom';

var UserItem =
/*#__PURE__*/
function (_React$PureComponent) {
  _inherits(UserItem, _React$PureComponent);

  function UserItem() {
    var _this;

    _classCallCheck(this, UserItem);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(UserItem).apply(this, arguments));

    _this.getSize = function (index) {
      if (index == 0) {
        return 80;
      } else if (index < 5) {
        return 50;
      } else {
        return 30;
      }
    };

    _this.getAvatar = function (index) {
      var data = _this.props.data;
      if (!data.User) return React.createElement("div", null);
      return React.createElement("div", {
        className: 'avatar-wrap',
        onClick: function onClick() {
          jumpPerson(data.User.UserId, 1);
        }
      }, React.createElement(AvatarImg, {
        src: data.User.PersonalPictureUrl ? data.User.PersonalPictureUrl.l : '',
        color: data.User.AvatarColor || '',
        size: _this.getSize(index),
        name: data.User.Name
      }));
    };

    return _this;
  }

  _createClass(UserItem, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this$props = this.props,
          index = _this$props.index,
          data = _this$props.data,
          rewarded = _this$props.rewarded;
      var size = this.getSize(index); //调整位置
      // debugger

      if (rewarded) {
        if (this.bag) {
          var len = getByteLen('红包元' + data.RewardAmount).len;
          var w = len * 6 + 18;
          this.bag.style.left = "".concat((size - w) / 2, "px");
          this.bag.style.width = "".concat(w, "px");
        }

        if (this.name) {
          var _len = data.User.Name ? getByteLen(data.User.Name).len : 0;

          var _w = _len * 6 + 18;

          this.name.style.marginLeft = "".concat((size - _w) / 2, "px");
          this.name.style.width = "".concat(_w, "px");
        }
      } else {
        if (this.bag) {
          var _len2 = data.User.Name ? getByteLen(data.User.Name).len : 0;

          var _w2 = _len2 * 6 + 18;

          this.bag.style.left = "".concat((size - _w2) / 2, "px");
          this.bag.style.width = "".concat(_w2, "px");
        }

        if (this.name) {
          var _len3 = getByteLen('打赏Ta').len;

          var _w3 = _len3 * 6 + 18;

          this.name.style.marginLeft = "".concat((size - _w3) / 2, "px");
          this.name.style.width = "".concat(_w3, "px");
        }
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props2 = this.props,
          index = _this$props2.index,
          position = _this$props2.position,
          data = _this$props2.data,
          rewarded = _this$props2.rewarded,
          handleGoReward = _this$props2.handleGoReward,
          shoTip = _this$props2.shoTip;
      if (!position) return null;
      var x = position.x,
          y = position.y;
      var TipShow = shoTip.includes(index);

      if (!rewarded) {
        return React.createElement("div", {
          className: 'user-item-wrap',
          style: {
            left: x + 'px',
            top: y + 'px'
          }
        }, React.createElement("span", {
          className: 'red-bag no-rewarded',
          style: {
            display: TipShow ? 'inline-block' : ''
          },
          ref: function ref(refs) {
            _this2.bag = refs;
          }
        }, data.User.Name), this.getAvatar(index), React.createElement("span", {
          className: 'name-wrap no-rewarded',
          ref: function ref(refs) {
            _this2.name = refs;
          },
          onClick: function onClick() {
            handleGoReward(data.User);
          }
        }, "\u6253\u8D4FTa"));
      }

      return React.createElement("div", {
        className: 'user-item-wrap',
        style: {
          left: x + 'px',
          top: y + 'px'
        }
      }, React.createElement("span", {
        className: 'red-bag',
        style: {
          display: TipShow ? 'inline-block' : ''
        },
        ref: function ref(refs) {
          _this2.bag = refs;
        }
      }, "\u7EA2\u5305", data.RewardAmount, "\u5143"), this.getAvatar(index), React.createElement("span", {
        className: 'name-wrap',
        ref: function ref(refs) {
          _this2.name = refs;
        },
        onClick: function onClick() {
          jumpPerson(data.User.UserId, 1);
        }
      }, data.User.Name));
    }
  }]);

  return UserItem;
}(React.PureComponent);

var Radar =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Radar, _React$Component);

  function Radar() {
    var _this3;

    _classCallCheck(this, Radar);

    _this3 = _possibleConstructorReturn(this, _getPrototypeOf(Radar).apply(this, arguments));
    _this3.subordinateUsersPos = [];
    _this3.state = {
      size: 0,
      shoTip: []
    };
    _this3.shoTip = [];
    _this3.height = 0;
    _this3.width = 0;

    _this3.getConfig = function () {
      //元素大小信息
      var configuration = [40, 25, 25, 25, 25, 15, 15, 15, 15, 15];
      return configuration;
    };

    _this3.getPosiotion = function () {
      _this3.pos = undefined;
      _this3.subordinateUsersPos = [];
      _this3.pos = new GetSpotPos(_this3.getSpotPos, _this3.getConfig(), _this3.props.size / 2);
    };

    _this3.getSpotPos = function (data) {
      var x = data.x,
          y = data.y;

      _this3.subordinateUsersPos.push({
        x: x,
        y: y
      });

      if (_this3.subordinateUsersPos.length == 10) {
        _this3.forceUpdate();
      }
    };

    _this3.getSize = function () {
      if (_this3.radar && _this3.radar.parentElement) {
        var h = _this3.radar.parentElement.clientHeight;
        var w = _this3.radar.parentElement.clientWidth;
        var min = Math.min(h, w);
        min != _this3.state.size && _this3.setState({
          size: min
        });
      }
    }; //不拖拽不重新计算位置刷新和toolTip不拖拽刷新冲突。


    _this3.stopInterval = function () {
      clearInterval(_this3.interval);
      var nodes = _this3.radar.childNodes;

      for (var i = 0; i < nodes.length; i++) {
        nodes[i].getElementsByClassName('red-bag')[0].style.display = '';
      }

      _this3.interval = undefined;
    }; // getArray=(num:number)=>{
    //     let tempArr:Array<number> = [];
    //     const {users} = this.props;
    //     let nodes = this.radar.childNodes;
    //     for(let i=0;i<nodes.length;i++){
    //         nodes[i].getElementsByClassName('red-bag')[0].style.display=''
    //     }
    //     for(let i = 0; i < num; i++){
    //         let j = Math.floor(Math.random()*users.length);
    //         tempArr.push(j);
    //         if(this.userItems && this.userItems.length && this.userItems[j]){
    //             let dom:any = ReactDom.findDOMNode(this.userItems[j]);
    //             if(dom){
    //                 dom.getElementsByClassName('red-bag')[0].style.display = 'inline-block';
    //             }
    //         }
    //     }
    //     return tempArr;
    // }


    _this3.getArray = function (num) {
      var temArr = [];
      var users = _this3.props.users;

      for (var i = 0; i < num; i++) {
        var j = Math.floor(Math.random() * users.length);
        temArr.push(j);
      }

      _this3.setState({
        shoTip: temArr
      });
    };

    _this3.resetTag = function () {
      //计算出 0-3 个随机数，随机数范围（0-9）；
      var num = Math.floor(Math.random() * 10 % 4); // 0-3个
      // let arr = this.getArray(num)//生成num个（0-9）的随机数。
      // this.shoTip = arr;

      _this3.getArray(num); //生成num个（0-9）的随机数。
      // this.setState({shoTip:arr});

    };

    _this3.reStartInterval = function () {
      var ipad = navigator.userAgent.toLowerCase().match(/ipad/i);

      if (ipad) {
        return;
      }

      clearInterval(_this3.interval);
      _this3.interval = undefined;
      _this3.interval = setInterval(_this3.resetTag, 3000);
    };

    return _this3;
  }

  _createClass(Radar, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.getSize();
      this.getPosiotion();
      this.reStartInterval();
    }
  }, {
    key: "shouldComponentUpdate",
    value: function shouldComponentUpdate() {
      var _this$props3 = this.props,
          pHeight = _this$props3.pHeight,
          pWidth = _this$props3.pWidth;

      if (pHeight == this.height && pWidth == this.width) {
        return false;
      } else {
        return true;
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      clearInterval(this.interval);
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      var backDom = document.getElementsByClassName('react-grid-placeholder')[0];

      if (backDom) {
        this.listenStart = true;
      }

      if (!backDom && this.listenStart) {
        this.listenStart = false;
        var _this$props4 = this.props,
            pHeight = _this$props4.pHeight,
            pWidth = _this$props4.pWidth;
        this.height = pHeight;
        this.width = pWidth;
        this.getPosiotion();
      }

      this.getSize();
    }
  }, {
    key: "render",
    value: function render() {
      var _this4 = this;

      var _this$props5 = this.props,
          users = _this$props5.users,
          rewarded = _this$props5.rewarded,
          handleGoReward = _this$props5.handleGoReward;
      var _this$state = this.state,
          size = _this$state.size,
          shoTip = _this$state.shoTip;
      if (!this.subordinateUsersPos.length) return null;
      this.userItems = new Array(users.length);
      return React.createElement("div", {
        className: 'radar-wrap',
        style: {
          width: size + 'px',
          height: size + 'px'
        },
        onMouseEnter: this.stopInterval,
        onMouseLeave: this.reStartInterval,
        ref: function ref(refs) {
          _this4.radar = refs;
        }
      }, !!users.length && users.map(function (user, k) {
        return React.createElement(UserItem, {
          key: "user-item".concat(k),
          shoTip: shoTip,
          ref: function ref(refs) {
            if (refs) {
              _this4.userItems[k] = refs;
            }
          },
          handleGoReward: handleGoReward,
          rewarded: rewarded,
          position: _this4.subordinateUsersPos[k],
          index: k,
          data: user
        });
      }));
    }
  }]);

  return Radar;
}(React.Component);

export { Radar as default };

==> ux-reward-wrap-3.1.11.tgz: package/lib/components/pageBuilder/ElementCollection/RewardWrap/Reward/Radar/index.js <==
import "core-js/modules/es6.regexp.match";
import "core-js/modules/es7.array.includes";
import "core-js/modules/es6.string.includes";
import "core-js/modules/es6.function.name";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import * as React from 'react';
import './index.css';
import AvatarImg from '../../../../../../components/common/avatarImg'; // import GetSpotPos from './GetSpotPos';

import GetSpotPos from './GetPosition';
import { getByteLen } from '../../../../../../helper';
import { jumpPerson } from '../../../../../../helper/jumpToPersonHome'; // import * as ReactDom from 'react-dom';

var UserItem =
/*#__PURE__*/
function (_React$PureComponent) {
  _inherits(UserItem, _React$PureComponent);

  function UserItem() {
    var _this;

    _classCallCheck(this, UserItem);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(UserItem).apply(this, arguments));

    _this.getSize = function (index) {
      if (index == 0) {
        return 80;
      } else if (index < 5) {
        return 50;
      } else {
        return 30;
      }
    };

    _this.getAvatar = function (index) {
      var data = _this.props.data;
      if (!data.User) return React.createElement("div", null);
      return React.createElement("div", {
        className: 'avatar-wrap',
        onClick: function onClick() {
          jumpPerson(data.User.UserId, 1);
        }
      }, React.createElement(AvatarImg, {
        src: data.User.PersonalPictureUrl ? data.User.PersonalPictureUrl.l : '',
        color: data.User.AvatarColor || '',
        size: _this.getSize(index),
        name: data.User.Name
      }));
    };

    return _this;
  }

  _createClass(UserItem, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this$props = this.props,
          index = _this$props.index,
          data = _this$props.data,
          rewarded = _this$props.rewarded;
      var size = this.getSize(index); //调整位置
      // debugger

      if (rewarded) {
        if (this.bag) {
          var len = getByteLen('红包元' + data.RewardAmount).len;
          var w = len * 6 + 18;
          this.bag.style.left = "".concat((size - w) / 2, "px");
          this.bag.style.width = "".concat(w, "px");
        }

        if (this.name) {
          var _len = data.User.Name ? getByteLen(data.User.Name).len : 0;

          var _w = _len * 6 + 18;

          this.name.style.marginLeft = "".concat((size - _w) / 2, "px");
          this.name.style.width = "".concat(_w, "px");
        }
      } else {
        if (this.bag) {
          var _len2 = data.User.Name ? getByteLen(data.User.Name).len : 0;

          var _w2 = _len2 * 6 + 18;

          this.bag.style.left = "".concat((size - _w2) / 2, "px");
          this.bag.style.width = "".concat(_w2, "px");
        }

        if (this.name) {
          var _len3 = getByteLen('打赏Ta').len;

          var _w3 = _len3 * 6 + 18;

          this.name.style.marginLeft = "".concat((size - _w3) / 2, "px");
          this.name.style.width = "".concat(_w3, "px");
        }
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props2 = this.props,
          index = _this$props2.index,
          position = _this$props2.position,
          data = _this$props2.data,
          rewarded = _this$props2.rewarded,
          handleGoReward = _this$props2.handleGoReward,
          shoTip = _this$props2.shoTip;
      if (!position) return null;
      var x = position.x,
          y = position.y;
      var TipShow = shoTip.includes(index);

      if (!rewarded) {
        return React.createElement("div", {
          className: 'user-item-wrap',
          style: {
            left: x + 'px',
            top: y + 'px'
          }
        }, React.createElement("span", {
          className: 'red-bag no-rewarded',
          style: {
            display: TipShow ? 'inline-block' : ''
          },
          ref: function ref(refs) {
            _this2.bag = refs;
          }
        }, data.User.Name), this.getAvatar(index), React.createElement("span", {
          className: 'name-wrap no-rewarded',
          ref: function ref(refs) {
            _this2.name = refs;
          },
          onClick: function onClick() {
            handleGoReward(data.User);
          }
        }, "\u6253\u8D4FTa"));
      }

      return React.createElement("div", {
        className: 'user-item-wrap',
        style: {
          left: x + 'px',
          top: y + 'px'
        }
      }, React.createElement("span", {
        className: 'red-bag',
        style: {
          display: TipShow ? 'inline-block' : ''
        },
        ref: function ref(refs) {
          _this2.bag = refs;
        }
      }, "\u7EA2\u5305", data.RewardAmount, data.RewardWay == 1 ? '元' : '积分'), this.getAvatar(index), React.createElement("span", {
        className: 'name-wrap',
        ref: function ref(refs) {
          _this2.name = refs;
        },
        onClick: function onClick() {
          jumpPerson(data.User.UserId, 1);
        }
      }, data.User.Name));
    }
  }]);

  return UserItem;
}(React.PureComponent);

var Radar =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Radar, _React$Component);

  function Radar() {
    var _this3;

    _classCallCheck(this, Radar);

    _this3 = _possibleConstructorReturn(this, _getPrototypeOf(Radar).apply(this, arguments));
    _this3.subordinateUsersPos = [];
    _this3.state = {
      size: 0,
      shoTip: []
    };
    _this3.shoTip = [];
    _this3.height = 0;
    _this3.width = 0;

    _this3.getConfig = function () {
      //元素大小信息
      var configuration = [40, 25, 25, 25, 25, 15, 15, 15, 15, 15];
      return configuration;
    };

    _this3.getPosiotion = function () {
      _this3.pos = undefined;
      _this3.subordinateUsersPos = [];
      _this3.pos = new GetSpotPos(_this3.getSpotPos, _this3.getConfig(), _this3.props.size / 2);
    };

    _this3.getSpotPos = function (data) {
      var x = data.x,
          y = data.y;

      _this3.subordinateUsersPos.push({
        x: x,
        y: y
      });

      if (_this3.subordinateUsersPos.length == 10) {
        _this3.forceUpdate();
      }
    };

    _this3.getSize = function () {
      if (_this3.radar && _this3.radar.parentElement) {
        var h = _this3.radar.parentElement.clientHeight;
        var w = _this3.radar.parentElement.clientWidth;
        var min = Math.min(h, w);
        min != _this3.state.size && _this3.setState({
          size: min
        });
      }
    }; //不拖拽不重新计算位置刷新和toolTip不拖拽刷新冲突。


    _this3.stopInterval = function () {
      clearInterval(_this3.interval);
      var nodes = _this3.radar.childNodes;

      for (var i = 0; i < nodes.length; i++) {
        nodes[i].getElementsByClassName('red-bag')[0].style.display = '';
      }

      _this3.interval = undefined;
    }; // getArray=(num:number)=>{
    //     let tempArr:Array<number> = [];
    //     const {users} = this.props;
    //     let nodes = this.radar.childNodes;
    //     for(let i=0;i<nodes.length;i++){
    //         nodes[i].getElementsByClassName('red-bag')[0].style.display=''
    //     }
    //     for(let i = 0; i < num; i++){
    //         let j = Math.floor(Math.random()*users.length);
    //         tempArr.push(j);
    //         if(this.userItems && this.userItems.length && this.userItems[j]){
    //             let dom:any = ReactDom.findDOMNode(this.userItems[j]);
    //             if(dom){
    //                 dom.getElementsByClassName('red-bag')[0].style.display = 'inline-block';
    //             }
    //         }
    //     }
    //     return tempArr;
    // }


    _this3.getArray = function (num) {
      var temArr = [];
      var users = _this3.props.users;

      for (var i = 0; i < num; i++) {
        var j = Math.floor(Math.random() * users.length);
        temArr.push(j);
      }

      _this3.setState({
        shoTip: temArr
      });
    };

    _this3.resetTag = function () {
      //计算出 0-3 个随机数，随机数范围（0-9）；
      var num = Math.floor(Math.random() * 10 % 4); // 0-3个
      // let arr = this.getArray(num)//生成num个（0-9）的随机数。
      // this.shoTip = arr;

      _this3.getArray(num); //生成num个（0-9）的随机数。
      // this.setState({shoTip:arr});

    };

    _this3.reStartInterval = function () {
      var ipad = navigator.userAgent.toLowerCase().match(/ipad/i);

      if (ipad) {
        return;
      }

      clearInterval(_this3.interval);
      _this3.interval = undefined;
      _this3.interval = setInterval(_this3.resetTag, 3000);
    };

    return _this3;
  }

  _createClass(Radar, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.getSize();
      this.getPosiotion();
      this.reStartInterval();
    }
  }, {
    key: "shouldComponentUpdate",
    value: function shouldComponentUpdate() {
      var _this$props3 = this.props,
          pHeight = _this$props3.pHeight,
          pWidth = _this$props3.pWidth;

      if (pHeight == this.height && pWidth == this.width) {
        return false;
      } else {
        return true;
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      clearInterval(this.interval);
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      var backDom = document.getElementsByClassName('react-grid-placeholder')[0];

      if (backDom) {
        this.listenStart = true;
      }

      if (!backDom && this.listenStart) {
        this.listenStart = false;
        var _this$props4 = this.props,
            pHeight = _this$props4.pHeight,
            pWidth = _this$props4.pWidth;
        this.height = pHeight;
        this.width = pWidth;
        this.getPosiotion();
      }

      this.getSize();
    }
  }, {
    key: "render",
    value: function render() {
      var _this4 = this;

      var _this$props5 = this.props,
          users = _this$props5.users,
          rewarded = _this$props5.rewarded,
          handleGoReward = _this$props5.handleGoReward;
      var _this$state = this.state,
          size = _this$state.size,
          shoTip = _this$state.shoTip;
      if (!this.subordinateUsersPos.length) return null;
      this.userItems = new Array(users.length);
      return React.createElement("div", {
        className: 'radar-wrap',
        style: {
          width: size + 'px',
          height: size + 'px'
        },
        onMouseEnter: this.stopInterval,
        onMouseLeave: this.reStartInterval,
        ref: function ref(refs) {
          _this4.radar = refs;
        }
      }, !!users.length && users.map(function (user, k) {
        return React.createElement(UserItem, {
          key: "user-item".concat(k),
          shoTip: shoTip,
          ref: function ref(refs) {
            if (refs) {
              _this4.userItems[k] = refs;
            }
          },
          handleGoReward: handleGoReward,
          rewarded: rewarded,
          position: _this4.subordinateUsersPos[k],
          index: k,
          data: user
        });
      }));
    }
  }]);

  return Radar;
}(React.Component);

export { Radar as default };
